@@ -60,7 +60,7 @@ else:
 
 GCE_METADATA_BASE = 'http://metadata.google.internal/computeMetadata/v1'
 GCE_METADATA_HEADERS = {'metadata-flavor': 'Google'}
-GCE_ENDPOINT_PROJECT = ('{}/project/project-id'.format((GCE_METADATA_BASE)))
+GCE_ENDPOINT_PROJECT = '{}/project/project-id'.format((GCE_METADATA_BASE))
 GCE_ENDPOINT_TOKEN = (
     '{}/instance/service-accounts'
     '/default/token?recursive=true'.format((GCE_METADATA_BASE))
